##  Required Knowledge
To work with the Reporting Framework and CLI, you should have a robust understanding of the following:
  * Command-line interface
  * A JavaScript framework of your choice
  * GraphQL APIs
  * REST APIs


Depending on the use case, you may need knowledge and skills in other areas.
